@@ -21,21 +21,24 @@
  */
 
 /**
- * SECTION:element-ivorbisdec
+ * SECTION:element-vorbisdec
+ * @short_description: a decoder that decodes Vorbis to raw audio
  * @see_also: vorbisenc, oggdemux
  *
+ * <refsect2>
+ * <para>
  * This element decodes a Vorbis stream to raw int audio.
  * <ulink url="http://www.vorbis.com/">Vorbis</ulink> is a royalty-free
  * audio codec maintained by the <ulink url="http://www.xiph.org/">Xiph.org
- * Foundation</ulink>. The decoder uses integer math to be more suitable for
- * embedded devices.
- * 
- * <refsect2>
+ * Foundation</ulink>.
+ * </para>
  * <title>Example pipelines</title>
- * |[
- * gst-launch -v filesrc location=sine.ogg ! oggdemux ! ivorbisdec ! audioconvert ! alsasink
- * ]| Decode an Ogg/Vorbis. To create an Ogg/Vorbis file refer to the
- * documentation of vorbisenc.
+ * <para>
+ * <programlisting>
+ * gst-launch -v filesrc location=sine.ogg ! oggdemux ! vorbisdec ! audioconvert ! alsasink
+ * </programlisting>
+ * Decode an Ogg/Vorbis. To create an Ogg/Vorbis file refer to the documentation of vorbisenc.
+ * </para>
  * </refsect2>
  *
  * Last reviewed on 2006-03-01 (0.10.4)
@@ -652,26 +655,23 @@ channel_count_error:
 static GstFlowReturn
 vorbis_handle_comment_packet (GstIVorbisDec * vd, ogg_packet * packet)
 {
+#if 0
   guint bitrate = 0;
   gchar *encoder = NULL;
-  GstTagList *list, *old_list;
+  GstTagList *list;
   GstBuffer *buf;
 
   GST_DEBUG_OBJECT (vd, "parsing comment packet");
 
-  buf = gst_buffer_new ();
-  GST_BUFFER_DATA (buf) = packet->packet->buffer->data;
-  GST_BUFFER_SIZE (buf) = packet->packet->buffer->size;
+  buf = gst_buffer_new_and_alloc (packet->bytes);
+  GST_BUFFER_DATA (buf) = packet->packet;
 
   list =
       gst_tag_list_from_vorbiscomment_buffer (buf, (guint8 *) "\003vorbis", 7,
       &encoder);
 
-  old_list = vd->taglist;
   vd->taglist = gst_tag_list_merge (vd->taglist, list, GST_TAG_MERGE_REPLACE);
 
-  if (old_list)
-    gst_tag_list_free (old_list);
   gst_tag_list_free (list);
   gst_buffer_unref (buf);
 
@@ -687,18 +687,18 @@ vorbis_handle_comment_packet (GstIVorbisDec * vd, ogg_packet * packet)
   gst_tag_list_add (vd->taglist, GST_TAG_MERGE_REPLACE,
       GST_TAG_ENCODER_VERSION, vd->vi.version,
       GST_TAG_AUDIO_CODEC, "Vorbis", NULL);
-  if (vd->vi.bitrate_nominal > 0 && vd->vi.bitrate_nominal <= 0x7FFFFFFF) {
+  if (vd->vi.bitrate_nominal > 0) {
     gst_tag_list_add (vd->taglist, GST_TAG_MERGE_REPLACE,
         GST_TAG_NOMINAL_BITRATE, (guint) vd->vi.bitrate_nominal, NULL);
     bitrate = vd->vi.bitrate_nominal;
   }
-  if (vd->vi.bitrate_upper > 0 && vd->vi.bitrate_upper <= 0x7FFFFFFF) {
+  if (vd->vi.bitrate_upper > 0) {
     gst_tag_list_add (vd->taglist, GST_TAG_MERGE_REPLACE,
         GST_TAG_MAXIMUM_BITRATE, (guint) vd->vi.bitrate_upper, NULL);
     if (!bitrate)
       bitrate = vd->vi.bitrate_upper;
   }
-  if (vd->vi.bitrate_lower > 0 && vd->vi.bitrate_lower <= 0x7FFFFFFF) {
+  if (vd->vi.bitrate_lower > 0) {
     gst_tag_list_add (vd->taglist, GST_TAG_MERGE_REPLACE,
         GST_TAG_MINIMUM_BITRATE, (guint) vd->vi.bitrate_lower, NULL);
     if (!bitrate)
@@ -719,7 +719,7 @@ vorbis_handle_comment_packet (GstIVorbisDec * vd, ogg_packet * packet)
     gst_element_post_message (GST_ELEMENT_CAST (vd),
         gst_message_new_tag (GST_OBJECT (vd), gst_tag_list_copy (vd->taglist)));
   }
-
+#endif
   return GST_FLOW_OK;
 }
 
