@@ -49,7 +49,6 @@ struct _GstNeonhttpSrc {
   ne_request *request;
   ne_uri uri;
   gchar *location;
-  gchar *query_string;
   ne_uri proxy;
   gchar *user_agent;
 
@@ -71,9 +70,6 @@ struct _GstNeonhttpSrc {
   /* enable Neon HTTP debug messages */
   gboolean neon_http_debug;
 
-  /* accept self-signed certificates */
-  gboolean accept_self_signed;
-
   gint64 read_position;
   gboolean seekable;
 };
