@@ -45,53 +45,25 @@ struct _GstAppSink
 
   /*< private >*/
   GstCaps *caps;
-  gboolean emit_signals;
-  guint max_buffers;
-  gboolean drop;
 
   GCond *cond;
   GMutex *mutex;
   GQueue *queue;
-  GstBuffer *preroll;
-  gboolean flushing;
-  gboolean started;
-  gboolean is_eos;
+  gboolean end_of_stream;
 };
 
 struct _GstAppSinkClass
 {
   GstBaseSinkClass basesink_class;
-
-  /* signals */
-  gboolean    (*eos)          (GstAppSink *sink);
-  gboolean    (*new_preroll)  (GstAppSink *sink);
-  gboolean    (*new_buffer)   (GstAppSink *sink);
-
-  /* actions */
-  GstBuffer * (*pull_preroll)  (GstAppSink *sink);
-  GstBuffer * (*pull_buffer)   (GstAppSink *sink);
 };
 
 GType gst_app_sink_get_type(void);
 
 GST_DEBUG_CATEGORY_EXTERN (app_sink_debug);
 
-void            gst_app_sink_set_caps         (GstAppSink *appsink, const GstCaps *caps);
-GstCaps *       gst_app_sink_get_caps         (GstAppSink *appsink);
-
-gboolean        gst_app_sink_is_eos           (GstAppSink *appsink);
-
-void            gst_app_sink_set_emit_signals (GstAppSink *appsink, gboolean emit);
-gboolean        gst_app_sink_get_emit_signals (GstAppSink *appsink);
-
-void            gst_app_sink_set_max_buffers  (GstAppSink *appsink, guint max);
-guint           gst_app_sink_get_max_buffers  (GstAppSink *appsink);
-
-void            gst_app_sink_set_drop         (GstAppSink *appsink, gboolean drop);
-gboolean        gst_app_sink_get_drop         (GstAppSink *appsink);
-
-GstBuffer *     gst_app_sink_pull_preroll     (GstAppSink *appsink);
-GstBuffer *     gst_app_sink_pull_buffer      (GstAppSink *appsink);
+void gst_app_sink_set_caps (GstAppSink *appsink, GstCaps *caps);
+gboolean gst_app_sink_end_of_stream (GstAppSink *appsink);
+GstBuffer *gst_app_sink_pull_buffer (GstAppSink *appsink);
 
 G_END_DECLS
 
