@@ -29,6 +29,12 @@
 #define GST_CAT_DEFAULT nsfdec_debug
 GST_DEBUG_CATEGORY_STATIC (GST_CAT_DEFAULT);
 
+static const GstElementDetails gst_nsfdec_details =
+GST_ELEMENT_DETAILS ("Nsf decoder",
+    "Codec/Decoder/Audio",
+    "Using nosefart to decode NSF audio tunes",
+    "Johan Dahlin <johan@gnome.org>");
+
 /* Nsfdec signals and args */
 enum
 {
@@ -102,7 +108,7 @@ static void gst_nsfdec_set_property (GObject * object, guint prop_id,
 
 static GstElementClass *parent_class = NULL;
 
-/* static guint gst_nsfdec_signals[LAST_SIGNAL] = { 0 }; */
+//static guint gst_nsfdec_signals[LAST_SIGNAL] = { 0 };
 
 GType
 gst_nsfdec_get_type (void)
@@ -136,10 +142,7 @@ gst_nsfdec_base_init (gpointer g_class)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
 
-  gst_element_class_set_details_simple (element_class, "Nsf decoder",
-      "Codec/Decoder/Audio",
-      "Using nosefart to decode NSF audio tunes",
-      "Johan Dahlin <johan@gnome.org>");
+  gst_element_class_set_details (element_class, &gst_nsfdec_details);
 
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&src_templ));
@@ -177,13 +180,17 @@ gst_nsfdec_class_init (GstNsfDec * klass)
 static void
 gst_nsfdec_init (GstNsfDec * nsfdec)
 {
-  nsfdec->sinkpad = gst_pad_new_from_static_template (&sink_templ, "sink");
+  nsfdec->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&sink_templ),
+      "sink");
   gst_pad_set_query_function (nsfdec->sinkpad, NULL);
   gst_pad_set_event_function (nsfdec->sinkpad, gst_nsfdec_sink_event);
   gst_pad_set_chain_function (nsfdec->sinkpad, gst_nsfdec_chain);
   gst_element_add_pad (GST_ELEMENT (nsfdec), nsfdec->sinkpad);
 
-  nsfdec->srcpad = gst_pad_new_from_static_template (&src_templ, "src");
+  nsfdec->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&src_templ),
+      "src");
   gst_pad_set_event_function (nsfdec->srcpad, gst_nsfdec_src_event);
   gst_pad_set_query_function (nsfdec->srcpad, gst_nsfdec_src_query);
   gst_pad_use_fixed_caps (nsfdec->srcpad);
@@ -211,9 +218,6 @@ gst_nsfdec_finalize (GObject * object)
   if (nsfdec->tune_buffer)
     gst_buffer_unref (nsfdec->tune_buffer);
 
-  if (nsfdec->taglist)
-    gst_tag_list_free (nsfdec->taglist);
-
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -370,22 +374,6 @@ start_play_tune (GstNsfDec * nsfdec)
   if (!nsfdec_negotiate (nsfdec))
     goto could_not_negotiate;
 
-  nsfdec->taglist = gst_tag_list_new ();
-  gst_tag_list_add (nsfdec->taglist, GST_TAG_MERGE_REPLACE,
-      GST_TAG_AUDIO_CODEC, "NES Sound Format", NULL);
-
-  if (nsfdec->nsf->artist_name)
-    gst_tag_list_add (nsfdec->taglist, GST_TAG_MERGE_REPLACE,
-        GST_TAG_ARTIST, nsfdec->nsf->artist_name, NULL);
-
-  if (nsfdec->nsf->song_name)
-    gst_tag_list_add (nsfdec->taglist, GST_TAG_MERGE_REPLACE,
-        GST_TAG_TITLE, nsfdec->nsf->song_name, NULL);
-
-  gst_element_post_message (GST_ELEMENT_CAST (nsfdec),
-      gst_message_new_tag (GST_OBJECT (nsfdec),
-          gst_tag_list_copy (nsfdec->taglist)));
-
   nsf_playtrack (nsfdec->nsf,
       nsfdec->tune_number, nsfdec->frequency, nsfdec->bits, nsfdec->stereo);
   nsf_setfilter (nsfdec->nsf, nsfdec->filter);
@@ -642,6 +630,6 @@ plugin_init (GstPlugin * plugin)
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR, GST_VERSION_MINOR,
-    "nsf",
+    "nsfdec",
     "Uses nosefart to decode .nsf files",
     plugin_init, VERSION, "GPL", GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN);
