@@ -1,4 +1,4 @@
-/* GStreamer NUV demuxer
+/* GStreamer
  * Copyright (C) <2006> Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
  *                      Rosfran Borges <rosfran.borges@indt.org.br>
  *
@@ -21,21 +21,24 @@
 
 /**
  * SECTION:element-nuvdemux
- * @see_also: mythtvsrc
  *
- * Demuxes MythTVs NuppelVideo .nuv file into raw or compressed audio and/or
- * video streams.
- * 
- * This element currently only supports pull-based scheduling.
- * 
  * <refsect2>
+ * <para>
+ * Demuxes an .nuv file into raw or compressed audio and/or video streams.
+ * </para>
+ * <para>
+ * This element currently only supports pull-based scheduling.
+ * </para>
  * <title>Example launch line</title>
- * |[
+ * <para>
+ * <programlisting>
  * gst-launch filesrc test.nuv ! nuvdemux name=demux  demux.audio_00 ! decodebin ! audioconvert ! audioresample ! autoaudiosink   demux.video_00 ! queue ! decodebin ! ffmpegcolorspace ! videoscale ! autovideosink
- * ]| Play (parse and decode) an .nuv file and try to output it to
+ * </programlisting>
+ * Play (parse and decode) an .nuv file and try to output it to
  * an automatically detected soundcard and videosink. If the NUV file contains
  * compressed audio or video data, this will only work if you have the
  * right decoder elements/plugins installed.
+ * </para>
  * </refsect2>
  *
  */
@@ -60,6 +63,13 @@ GST_DEBUG_CATEGORY_STATIC (nuvdemux_debug);
 
 GST_DEBUG_CATEGORY_EXTERN (GST_CAT_EVENT);
 
+static const GstElementDetails gst_nuv_demux_details =
+GST_ELEMENT_DETAILS ("Nuv demuxer",
+    "Codec/Demuxer",
+    "Demultiplex a .nuv file into audio and video",
+    "Renato Araujo Oliveira Filho <renato.filho@indt.org.br>,"
+    "Rosfran Borges <rosfran.borges@indt.org.br>");
+
 static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
@@ -132,11 +142,7 @@ gst_nuv_demux_base_init (gpointer klass)
 
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&sink_template));
-  gst_element_class_set_details_simple (element_class, "Nuv demuxer",
-      "Codec/Demuxer",
-      "Demultiplex a MythTV NuppleVideo .nuv file into audio and video",
-      "Renato Araujo Oliveira Filho <renato.filho@indt.org.br>,"
-      "Rosfran Borges <rosfran.borges@indt.org.br>");
+  gst_element_class_set_details (element_class, &gst_nuv_demux_details);
 }
 
 static void
@@ -145,10 +151,13 @@ gst_nuv_demux_class_init (GstNuvDemuxClass * klass)
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (klass);
   GObjectClass *gobject_class = (GObjectClass *) klass;
 
-  gobject_class->finalize = gst_nuv_demux_finalize;
+  GST_DEBUG_CATEGORY_INIT (nuvdemux_debug, "nuvdemux",
+      0, "Demuxer for NUV streams");
 
-  gstelement_class->change_state =
-      GST_DEBUG_FUNCPTR (gst_nuv_demux_change_state);
+  parent_class = g_type_class_peek_parent (klass);
+
+  gobject_class->finalize = gst_nuv_demux_finalize;
+  gstelement_class->change_state = gst_nuv_demux_change_state;
 }
 
 static void
@@ -188,14 +197,13 @@ gst_nuv_demux_finalize (GObject * object)
   gst_nuv_demux_destoy_src_pad (nuv);
   gst_nuv_demux_reset (nuv);
   if (nuv->adapter != NULL) {
-    g_object_unref (nuv->adapter);
-    nuv->adapter = NULL;
+    gst_object_unref (nuv->adapter);
   }
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 /*****************************************************************************
- * Utils functions
+ * Utils fucntions
  *****************************************************************************/
 
 static gboolean
@@ -374,9 +382,8 @@ gst_nuv_demux_extended_header_load (GstNuvDemux * nuv,
 
   GST_DEBUG_OBJECT (nuv,
       "ex hdr: v=%d vffc=%4.4s afcc=%4.4s %dHz %dbits ach=%d acr=%d aq=%d"
-      "rtjpeg q=%d lf=%d lc=%d lavc br=%d qmin=%d qmax=%d maxqdiff=%d seekableoff=%"
-      G_GINT64_FORMAT " keyfao=%" G_GINT64_FORMAT, h->i_version,
-      (gchar *) & h->i_video_fcc, (gchar *) & h->i_audio_fcc,
+      "rtjpeg q=%d lf=%d lc=%d lavc br=%d qmin=%d qmax=%d maxqdiff=%d seekableoff=%lld keyfao=%lld",
+      h->i_version, (gchar *) & h->i_video_fcc, (gchar *) & h->i_audio_fcc,
       h->i_audio_sample_rate, h->i_audio_bits_per_sample, h->i_audio_channels,
       h->i_audio_compression_ratio, h->i_audio_quality, h->i_rtjpeg_quality,
       h->i_rtjpeg_luma_filter, h->i_rtjpeg_chroma_filter, h->i_lavc_bitrate,
@@ -635,9 +642,9 @@ gst_nuv_demux_stream_extend_header (GstNuvDemux * nuv)
     nuv->state = GST_NUV_DEMUX_EXTEND_HEADER_DATA;
   } else {
     nuv->state = GST_NUV_DEMUX_INVALID_DATA;
-    GST_ELEMENT_ERROR (nuv, STREAM, DEMUX, (NULL),
-        ("Unsupported extended header (0x%02x)", buf->data[0]));
     g_object_unref (buf);
+    GST_ELEMENT_WARNING (nuv, STREAM, FAILED,
+        (_("incomplete NUV support")), ("incomplete NUV support"));
     return GST_FLOW_ERROR;
   }
   return res;
@@ -798,16 +805,11 @@ gst_nuv_demux_sink_activate (GstPad * sinkpad)
 
   if (gst_pad_check_pull_range (sinkpad)) {
     nuv->mode = 0;
-    if (nuv->adapter != NULL) {
-      g_object_unref (nuv->adapter);
-      nuv->adapter = NULL;
-    }
+    nuv->adapter = NULL;
     res = gst_pad_activate_pull (sinkpad, TRUE);
   } else {
     nuv->mode = 1;
-    if (!nuv->adapter) {
-      nuv->adapter = gst_adapter_new ();
-    }
+    nuv->adapter = gst_adapter_new ();
     res = gst_pad_activate_push (sinkpad, TRUE);
   }
 
@@ -919,12 +921,8 @@ done:
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  GST_DEBUG_CATEGORY_INIT (nuvdemux_debug, "nuvdemux",
-      0, "Demuxer for NUV streams");
-
 #ifdef ENABLE_NLS
-  GST_DEBUG ("binding text domain %s to locale dir %s", GETTEXT_PACKAGE,
-      LOCALEDIR);
+  setlocale (LC_ALL, "");
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 #endif /* ENABLE_NLS */
 
@@ -938,5 +936,5 @@ plugin_init (GstPlugin * plugin)
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     "nuvdemux",
-    "Demuxes MythTV NuppelVideo files",
-    plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
+    "Demuxes and muxes audio and video",
+    plugin_init, VERSION, "LGPL", "NuvDemux", "")
